searchData={"items":[{"type":"module","title":"UnicodeSmuggler","doc":"# UnicodeSmuggler\n\nBecause it seemed like a good idea at the time, this is a quick implementation of the ideas in\nPaul Butler's blog post [Smuggling arbitrary data through an emoji](https://paulbutler.org/2025/smuggling-arbitrary-data-through-an-emoji/)\nas a small Elixir package.\n\nUnicodeSmuggler is a simple stenography utility that will hide text by attaching it to any Unicode character\nas a list of invisible \"variation selectors\". The character will render as normal in most unicode-compatible\napplications. UnicodeSmuggler (or anything else compatible with Paul Butler's code) can later be used to extract the hidden text.\n\nAs Paul makes clear this is, at best, an underhand hack and misuse of the Unicode standard. On the other hand,\nit's an interesting trick, I thought it would be fun to implement, and this library may possibly be of use\nfor detecting such tricks in the wild.","ref":"UnicodeSmuggler.html"},{"type":"module","title":"Features - UnicodeSmuggler","doc":"* Encode text in a Unicode character\n* Decode text hidden in a Unicode character\n* Find hidden text in a string\n* Remove hidden text from a Unicode character\n* Accidentally confuse JetBrains' IDEs like RubyMine and cause mysterious problems in your own tests\n* Ducks","ref":"UnicodeSmuggler.html#module-features"},{"type":"module","title":"Examples - UnicodeSmuggler","doc":"","ref":"UnicodeSmuggler.html#module-examples"},{"type":"module","title":"Encoding - UnicodeSmuggler","doc":"```elixir\nUnicodeSmuggler.encode!(\"Aw yiss!\")\n# => \"🦆󠄱󠅧󠄐󠅩󠅙󠅣󠅣\"\n```","ref":"UnicodeSmuggler.html#module-encoding"},{"type":"module","title":"Decoding - UnicodeSmuggler","doc":"```elixir\nUnicodeSmuggler.decode!(\"🦆󠄱󠅧󠄐󠅩󠅙󠅣󠅣\")\n# => \"Aw yiss!\"\n```","ref":"UnicodeSmuggler.html#module-decoding"},{"type":"module","title":"Trimming - UnicodeSmuggler","doc":"```elixir\nUnicodeSmuggler.trim(\"🦆󠄱󠅧󠄐󠅩󠅙󠅣󠅣\")\n|> UnicodeSmuggler.decode!()\n# => nil\n```","ref":"UnicodeSmuggler.html#module-trimming"},{"type":"function","title":"UnicodeSmuggler.decode!/1","doc":"Decodes and returns the hidden text in the specified container character.\n\nA nil value will be returned if no text has been hidden.","ref":"UnicodeSmuggler.html#decode!/1"},{"type":"function","title":"UnicodeSmuggler.encode!/2","doc":"Hides the text passed as the first parameter in the container character passed as the second parameter.\n\nIf no container character is specified then a duck will be returned.","ref":"UnicodeSmuggler.html#encode!/2"},{"type":"function","title":"UnicodeSmuggler.ensure_single!/1","doc":"","ref":"UnicodeSmuggler.html#ensure_single!/1"},{"type":"function","title":"UnicodeSmuggler.scan/1","doc":"Scans a string for hidden text and returns any found fragments in a list.\n\nIf no hidden text is found an empty list will be returned.","ref":"UnicodeSmuggler.html#scan/1"},{"type":"function","title":"UnicodeSmuggler.smuggling?/1","doc":"Returns true if hidden text is found in the passed string, otherwise false.","ref":"UnicodeSmuggler.html#smuggling?/1"},{"type":"function","title":"UnicodeSmuggler.trim/1","doc":"Accepts a single character and returns it without hidden text. Hopefully.","ref":"UnicodeSmuggler.html#trim/1"},{"type":"extras","title":"UnicodeSmuggler","doc":"# UnicodeSmuggler\n\nBecause it seemed like a good idea at the time, this is a quick implementation of the ideas in \nPaul Butler's blog post [Smuggling arbitrary data through an emoji](https://paulbutler.org/2025/smuggling-arbitrary-data-through-an-emoji/)\nas a small Elixir package.\n\nUnicodeSmuggler is a simple stenography utility that will hide text by attaching it to any Unicode character\nas a list of invisible \"variation selectors\". The character will render as normal in most unicode-compatible\napplications. UnicodeSmuggler (or anything else compatible with Paul Butler's code) can later be used to extract the hidden text.\n\nAs Paul makes clear this is, at best, an underhand hack and misuse of the Unicode standard. On the other hand,\nit's an interesting trick, I thought it would be fun to implement, and this library may possibly be of use\nfor detecting such tricks in the wild.","ref":"readme.html"},{"type":"extras","title":"Features - UnicodeSmuggler","doc":"* Encode text in a Unicode character\n* Decode text hidden in a Unicode character\n* Find hidden text in a string\n* Remove hidden text from a Unicode character\n* Accidentally confuse JetBrains' IDEs like RubyMine and cause mysterious problems in your own tests\n* Ducks","ref":"readme.html#features"},{"type":"extras","title":"Examples - UnicodeSmuggler","doc":"","ref":"readme.html#examples"},{"type":"extras","title":"Encoding - UnicodeSmuggler","doc":"```elixir\n  UnicodeSmuggler.encode!(\"Aw yiss!\")\n  # => \"🦆󠄱󠅧󠄐󠅩󠅙󠅣󠅣\"\n```","ref":"readme.html#encoding"},{"type":"extras","title":"Decoding - UnicodeSmuggler","doc":"```elixir\n  UnicodeSmuggler.decode!(\"🦆󠄱󠅧󠄐󠅩󠅙󠅣󠅣\")\n  # => \"Aw yiss!\"\n```","ref":"readme.html#decoding"},{"type":"extras","title":"Trimming - UnicodeSmuggler","doc":"```elixir\n  UnicodeSmuggler.trim(\"🦆󠄱󠅧󠄐󠅩󠅙󠅣󠅣\")\n  |> UnicodeSmuggler.decode!()\n  # => nil\n```","ref":"readme.html#trimming"},{"type":"extras","title":"Installation - UnicodeSmuggler","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `unicode_smuggler` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:unicode_smuggler, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - UnicodeSmuggler","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"Contributing - UnicodeSmuggler","doc":"You can request new features by creating an [issue](https://github.com/binaryape/unicode_smuggler/issues),\nor submit a [pull request](https://github.com/binaryape/unicode_smuggler/pulls) with your contribution.","ref":"readme.html#contributing"},{"type":"extras","title":"Copyright and License - UnicodeSmuggler","doc":"Copyright (c) 2025 Pete Birkinshaw\n\nUnicodeSmuggler is MIT licensed.","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"Disclaimer - UnicodeSmuggler","doc":"Use at your own risk","ref":"readme.html#disclaimer"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2025 Pete Birkinshaw\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}